==> org-lsst-ccs-subsystem-fcs-gui-4.0.12-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselGUI.java <==
package org.lsst.ccs.subsystems.fcs.carousel.ui;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import org.lsst.ccs.Agent;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.messaging.AgentMessagingLayer;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.ui.commons.GeneralPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.GeneralGUI;

/**
 * A GUI for the carousel in standalone mode.
 * 
 * @author virieux
 */
public class CarouselGUI extends GeneralGUI implements InterfaceCarouselGUI {
    private static final long serialVersionUID = 3716082311687590505L;
    
    private final long timeoutForOpeningClamps = 10000;
    private final long timeoutForRotation = 10000;
    private final long timeoutForCheckingFilterLocation = 2000;
    private final long timeoutForCANbus = 500;

    /**
     * A constructor with a name, a destination (subsystem name) and an AgentMessagingLayer.
     * @param name
     * @param destination
     * @param aml 
     */
    public CarouselGUI(String name, String destination, AgentMessagingLayer aml) {
        super(name, destination, aml);
        CarouselGatherPanel carouselGatherPanel;
        carouselGatherPanel = new CarouselGatherPanel(this, CHANGER_TCPPROXY_NAME);
        CarouselBottomPanel carouselBottomPanel = new CarouselBottomPanel(carouselGatherPanel, "CAROUSEL");
        this.generalPanel = new GeneralPanel(this, carouselBottomPanel);
        pane = new JScrollPane(generalPanel);
    }
    
    @Override
    public String getName() {
        return "CarouselGUIModule";
    }
    
    /**
     * Check Filter Location
     */
    @Override
    public void checkFiltersLocation() {
        new CommandSwingWorker("checkFiltersLocation", this.timeoutForCheckingFilterLocation).execute();
    }
    
    /**
     ******************************************************************************
     ** Carousel Rotation
     * *****************************************************************************
     */
    @Override
    public void rotate() {
        FCSLOG.info("Carousel rotating");
        FCSLOG.info("/timeout=" + this.timeoutForRotation);
        new CommandSwingWorker("rotate", this.timeoutForRotation, "carousel").execute();
    }
    
 
    @Override
    public void updatePosition() {
        FCSLOG.info("Carousel updating position");
        FCSLOG.info("/timeout=" + this.timeoutForRotation);
        new CommandSwingWorker("updatePosition", this.timeoutForCANbus, "carousel").execute();        
    }   


    /**
     ******************************************************************************
     ** end of Trucks Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Clamps Actions
     * *****************************************************************************
     */
    @Override
    public void unlockClamps() {
        FCSLOG.info("Carousel unlocking clamps");
        FCSLOG.info("/timeout=" + timeoutForOpeningClamps);
        new GeneralGUI.CommandSwingWorker("unlockClamps", this.timeoutForOpeningClamps).execute();
    }

    /**
     ******************************************************************************
     ** end of Clamps Actions
     * *****************************************************************************
     */


    
     /**
     * This main launches an carousel GUI for the subsystem "carousel".
     * It's used only for tests.
     * 
     * @param args the command line arguments
     */
    public static void main(String[] args) {

        Agent agent = new Agent("CarouselGUI", AgentInfo.AgentType.CONSOLE);
        CarouselGUI t = new CarouselGUI(agent.getName(), "carousel", 
                agent.getMessagingAccess());
        agent.start();

        JFrame frame = new JFrame("Carousel View GUI");
        frame.setContentPane(t.getGuiLayout());
        frame.pack();
        frame.setVisible(true);
        t.initGui();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }



    
}

==> org-lsst-ccs-subsystem-fcs-gui-5.0.4-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselGUI.java <==
package org.lsst.ccs.subsystems.fcs.carousel.ui;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import org.lsst.ccs.Agent;
import org.lsst.ccs.bus.data.AgentInfo;
import org.lsst.ccs.messaging.AgentMessagingLayer;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import org.lsst.ccs.subsystems.fcs.ui.commons.GeneralPanel;
import org.lsst.ccs.subsystems.fcs.ui.commons.GeneralGUI;

/**
 * A GUI for the carousel in standalone mode.
 * 
 * @author virieux
 */
public class CarouselGUI extends GeneralGUI implements InterfaceCarouselGUI {
    private static final long serialVersionUID = 3716082311687590505L;
    
    private final long timeoutForOpeningClamps = 10000;
    private final long timeoutForRotation = 10000;
    private final long timeoutForCheckingFilterLocation = 2000;
    private final long timeoutForCANbus = 500;

    /**
     * A constructor with a name, a destination (subsystem name) and an AgentMessagingLayer.
     * @param name
     * @param role
     * @param aml 
     */
    public CarouselGUI(String name, String role, AgentMessagingLayer aml) {
        super(name, role, aml);
        CarouselGatherPanel carouselGatherPanel;
        carouselGatherPanel = new CarouselGatherPanel(this, CHANGER_TCPPROXY_NAME);
        CarouselBottomPanel carouselBottomPanel = new CarouselBottomPanel(carouselGatherPanel, "CAROUSEL");
        this.generalPanel = new GeneralPanel(this, carouselBottomPanel);
        pane = new JScrollPane(generalPanel);
    }
    
    @Override
    public String getName() {
        return "CarouselGUIModule";
    }
    
    /**
     * Check Filter Location
     */
    @Override
    public void checkFiltersLocation() {
        new CommandSwingWorker("checkFiltersLocation", this.timeoutForCheckingFilterLocation).execute();
    }
    
    /**
     ******************************************************************************
     ** Carousel Rotation
     * *****************************************************************************
     */
    @Override
    public void rotate() {
        FCSLOG.info("Carousel rotating");
        FCSLOG.info("/timeout=" + this.timeoutForRotation);
        new CommandSwingWorker("rotate", this.timeoutForRotation, "carousel").execute();
    }
    
 
    @Override
    public void updatePosition() {
        FCSLOG.info("Carousel updating position");
        FCSLOG.info("/timeout=" + this.timeoutForRotation);
        new CommandSwingWorker("updatePosition", this.timeoutForCANbus, "carousel").execute();        
    }   


    /**
     ******************************************************************************
     ** end of Trucks Actions
     * *****************************************************************************
     */
    /**
     ******************************************************************************
     ** Clamps Actions
     * *****************************************************************************
     */
    @Override
    public void unlockClamps() {
        FCSLOG.info("Carousel unlocking clamps");
        FCSLOG.info("/timeout=" + timeoutForOpeningClamps);
        new GeneralGUI.CommandSwingWorker("unlockClamps", this.timeoutForOpeningClamps).execute();
    }

    /**
     ******************************************************************************
     ** end of Clamps Actions
     * *****************************************************************************
     */


    
     /**
     * This main launches an carousel GUI for the subsystem "carousel".
     * It's used only for tests.
     * 
     * @param args the command line arguments
     */
    public static void main(String[] args) {

        Agent agent = new Agent("CarouselGUI", AgentInfo.AgentType.CONSOLE);
        CarouselGUI t = new CarouselGUI(agent.getName(), "carousel", 
                agent.getMessagingAccess());
        agent.start();

        JFrame frame = new JFrame("Carousel View GUI");
        frame.setContentPane(t.getGuiLayout());
        frame.pack();
        frame.setVisible(true);
        t.initGui();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }



    
}
